==> nativescript-2.3.0-2016-08-15-6541.tgz: package/lib/services/livesync/ios-platform-livesync-service.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var platform_livesync_service_base_1 = require("./platform-livesync-service-base");
var IOSPlatformLiveSyncService = (function (_super) {
    __extends(IOSPlatformLiveSyncService, _super);
    function IOSPlatformLiveSyncService(_liveSyncData, $devicesService, $mobileHelper, $logger, $options, $deviceAppDataFactory, $fs, $injector, $projectFilesManager, $projectFilesProvider, $liveSyncProvider) {
        _super.call(this, _liveSyncData, $devicesService, $mobileHelper, $logger, $options, $deviceAppDataFactory, $fs, $injector, $projectFilesManager, $projectFilesProvider, $liveSyncProvider);
        this.$devicesService = $devicesService;
        this.$mobileHelper = $mobileHelper;
        this.$logger = $logger;
        this.$options = $options;
        this.$deviceAppDataFactory = $deviceAppDataFactory;
        this.$fs = $fs;
        this.$injector = $injector;
        this.$projectFilesManager = $projectFilesManager;
        this.$projectFilesProvider = $projectFilesProvider;
        this.$liveSyncProvider = $liveSyncProvider;
    }
    IOSPlatformLiveSyncService.prototype.fullSync = function (postAction) {
        var _this = this;
        return (function () {
            var appIdentifier = _this.liveSyncData.appIdentifier;
            var platform = _this.liveSyncData.platform;
            var projectFilesPath = _this.liveSyncData.projectFilesPath;
            var canExecute = _this.getCanExecuteAction(platform, appIdentifier);
            var action = function (device) {
                return (function () {
                    var deviceAppData = _this.$deviceAppDataFactory.create(appIdentifier, _this.$mobileHelper.normalizePlatformName(platform), device);
                    var installed = _this.tryInstallApplication(device, deviceAppData).wait();
                    var localToDevicePaths = _this.$projectFilesManager.createLocalToDevicePaths(deviceAppData, projectFilesPath, null, _this.liveSyncData.excludedProjectDirsAndFiles);
                    var afterSyncAction;
                    if (installed) {
                        afterSyncAction = function () { return device.applicationManager.tryStartApplication(deviceAppData.appIdentifier); };
                    }
                    else {
                        _this.transferFiles(deviceAppData, localToDevicePaths, _this.liveSyncData.projectFilesPath, true).wait();
                        afterSyncAction = function () { return _this.refreshApplication(deviceAppData, localToDevicePaths); };
                    }
                    if (postAction) {
                        return postAction(deviceAppData, localToDevicePaths).wait();
                    }
                    return afterSyncAction().wait();
                }).future()();
            };
            _this.$devicesService.execute(action, canExecute).wait();
        }).future()();
    };
    return IOSPlatformLiveSyncService;
}(platform_livesync_service_base_1.PlatformLiveSyncServiceBase));
$injector.register("iosPlatformLiveSyncServiceLocator", { factory: IOSPlatformLiveSyncService });

==> nativescript-2.4.0-2016-10-03-6732.tgz: package/lib/services/livesync/ios-platform-livesync-service.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var platform_livesync_service_base_1 = require("./platform-livesync-service-base");
var IOSPlatformLiveSyncService = (function (_super) {
    __extends(IOSPlatformLiveSyncService, _super);
    function IOSPlatformLiveSyncService(_liveSyncData, $devicesService, $mobileHelper, $logger, $options, $deviceAppDataFactory, $fs, $injector, $projectFilesManager, $projectFilesProvider, $liveSyncProvider) {
        _super.call(this, _liveSyncData, $devicesService, $mobileHelper, $logger, $options, $deviceAppDataFactory, $fs, $injector, $projectFilesManager, $projectFilesProvider, $liveSyncProvider);
        this.$devicesService = $devicesService;
        this.$mobileHelper = $mobileHelper;
        this.$logger = $logger;
        this.$options = $options;
        this.$deviceAppDataFactory = $deviceAppDataFactory;
        this.$fs = $fs;
        this.$injector = $injector;
        this.$projectFilesManager = $projectFilesManager;
        this.$projectFilesProvider = $projectFilesProvider;
        this.$liveSyncProvider = $liveSyncProvider;
    }
    IOSPlatformLiveSyncService.prototype.fullSync = function (postAction) {
        var _this = this;
        return (function () {
            var appIdentifier = _this.liveSyncData.appIdentifier;
            var platform = _this.liveSyncData.platform;
            var projectFilesPath = _this.liveSyncData.projectFilesPath;
            var canExecute = _this.getCanExecuteAction(platform, appIdentifier);
            var action = function (device) {
                return (function () {
                    var deviceAppData = _this.$deviceAppDataFactory.create(appIdentifier, _this.$mobileHelper.normalizePlatformName(platform), device);
                    var installed = _this.tryInstallApplication(device, deviceAppData).wait();
                    var localToDevicePaths = _this.$projectFilesManager.createLocalToDevicePaths(deviceAppData, projectFilesPath, null, _this.liveSyncData.excludedProjectDirsAndFiles);
                    var afterSyncAction;
                    if (installed) {
                        afterSyncAction = function () { return device.applicationManager.tryStartApplication(deviceAppData.appIdentifier); };
                    }
                    else {
                        _this.transferFiles(deviceAppData, localToDevicePaths, _this.liveSyncData.projectFilesPath, true).wait();
                        afterSyncAction = function () { return _this.refreshApplication(deviceAppData, localToDevicePaths); };
                    }
                    if (postAction) {
                        _this.finishLivesync(deviceAppData).wait();
                        return postAction(deviceAppData, localToDevicePaths).wait();
                    }
                    afterSyncAction().wait();
                    _this.finishLivesync(deviceAppData).wait();
                }).future()();
            };
            _this.$devicesService.execute(action, canExecute).wait();
        }).future()();
    };
    return IOSPlatformLiveSyncService;
}(platform_livesync_service_base_1.PlatformLiveSyncServiceBase));
$injector.register("iosPlatformLiveSyncServiceLocator", { factory: IOSPlatformLiveSyncService });
